==> order-center-api-2.9.0-CLOUD-20220819.123154-6-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqAddressBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/14 10:47
 */
@Data
public class UocCreateOrderServiceReqAddressBo implements Serializable {

    private static final long serialVersionUID = 7671275268061767695L;

    @DocField(value = "联系人国家编号")
    private String contactCountryId;

    @DocField(value = "联系人国家名称")
    private String contactCountryName;

    @DocField(value = "联系人省份编号", required = true)
    private String contactProvinceId;

    @DocField(value = "联系人省份名称", required = true)
    private String contactProvinceName;

    @DocField(value = "联系人地市编号", required = true)
    private String contactCityId;

    @DocField(value = "联系人地市名称", required = true)
    private String contactCityName;

    @DocField(value = "联系人区县编号", required = true)
    private String contactCountyId;

    @DocField(value = "联系人区县名称", required = true)
    private String contactCountyName;

    @DocField(value = "联系人乡镇编号")
    private String contactTownId;

    @DocField(value = "联系人乡镇名称")
    private String contactTown;

    @DocField(value = "收货人地址", required = true)
    private String contactAddress;

    @DocField(value = "联系人公司")
    private String contactCompany;

    @DocField(value = "联系人名称", required = true)
    private String contactName;

    @DocField(value = "联系人固话")
    private String contactFixPhone;

    @DocField(value = "联系人邮件", required = true)
    private String contactEmail;

    @DocField(value = "联系人手机", required = true)
    private String contactMobile;


}

==> order-center-api-3.0.0-CLOUD-20251111.094209-89-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqAddressBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/14 10:47
 */
@Data
public class UocCreateOrderServiceReqAddressBo implements Serializable {

    private static final long serialVersionUID = 7671275268061767695L;

    /**
     * 联系人国家编号
     */
    private String contactCountryId;

    /**
     * 联系人国家名称
     */
    private String contactCountryName;

    /**
     * 联系人省份编号
     */
    private String contactProvinceId;

    /**
     * 联系人省份名称
     */
    private String contactProvinceName;

    /**
     * 联系人地市编号
     */
    private String contactCityId;

    /**
     * 联系人地市名称
     */
    private String contactCityName;

    /**
     * 联系人区县编号
     */
    private String contactCountyId;

    /**
     * 联系人区县名称
     */
    private String contactCountyName;

    /**
     * 联系人乡镇编号
     */
    private String contactTownId;

    /**
     * 联系人乡镇名称
     */
    private String contactTown;

    /**
     * 收货人地址
     */
    private String contactAddress;

    /**
     * 联系人公司
     */
    private String contactCompany;

    /**
     * 联系人名称
     */
    private String contactName;

    /**
     * 联系人固话
     */
    private String contactFixPhone;

    /**
     * 联系人邮件
     */
    private String contactEmail;

    /**
     * 联系人手机
     */
    private String contactMobile;
    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;

    /**
     * 区号
     */
    private String areaCode;

}
